# pygis

[![image](https://img.shields.io/pypi/v/pygis.svg)](https://pypi.python.org/pypi/pygis)
[![image](https://img.shields.io/conda/vn/conda-forge/pygis.svg)](https://anaconda.org/conda-forge/pygis)
[![image](https://pepy.tech/badge/pygis)](https://pepy.tech/project/pygis)
[![Conda Downloads](https://img.shields.io/conda/dn/conda-forge/pygis.svg)](https://anaconda.org/conda-forge/pygis)
[![Conda Recipe](https://img.shields.io/badge/recipe-pygis-green.svg)](https://github.com/conda-forge/pygis-feedstock)
[![image](https://img.shields.io/badge/YouTube-Channel-red)](https://www.youtube.com/c/QiushengWu)
[![image](https://img.shields.io/twitter/follow/giswqs?style=social)](https://twitter.com/giswqs)

**A Python package for installing optional dependencies for geemap and leafmap.**

- Free software: MIT license
- Documentation: https://pygis.gishub.org

[![](https://i.imgur.com/bKFts2R.png)](https://pygis.gishub.org)

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
